package com.sundot.airport.equipment.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.sundot.airport.equipment.domain.EquipmentLedger;

/**
 * 设备台账Mapper接口
 *
 * @author ruoyi
 * @date 2026-05-12
 */
public interface EquipmentLedgerMapper extends BaseMapper<EquipmentLedger> {
    /**
     * 查询设备台账
     *
     * @param id 设备台账主键
     * @return 设备台账
     */
    public EquipmentLedger selectEquipmentLedgerById(Long id);

    /**
     * 查询设备台账列表
     *
     * @param equipmentLedger 设备台账
     * @return 设备台账集合
     */
    public List<EquipmentLedger> selectEquipmentLedgerList(EquipmentLedger equipmentLedger);

    /**
     * 新增设备台账
     *
     * @param equipmentLedger 设备台账
     * @return 结果
     */
    public int insertEquipmentLedger(EquipmentLedger equipmentLedger);

    /**
     * 修改设备台账
     *
     * @param equipmentLedger 设备台账
     * @return 结果
     */
    public int updateEquipmentLedger(EquipmentLedger equipmentLedger);

    /**
     * 删除设备台账
     *
     * @param id 设备台账主键
     * @return 结果
     */
    public int deleteEquipmentLedgerById(Long id);

    /**
     * 批量删除设备台账
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEquipmentLedgerByIds(Long[] ids);

    /**
     * 查询定/自检到期日期已过期的设备列表
     *
     * @return 设备台账集合
     */
    public List<EquipmentLedger> selectExpiredInspectionList();

    /**
     * 查询一月内定/自检到期的设备列表
     *
     * @return 设备台账集合
     */
    public List<EquipmentLedger> selectUpcomingInspectionList();

    /**
     * 查询两周内定/自检到期的设备列表
     *
     * @return 设备台账集合
     */
    public List<EquipmentLedger> selectTwoWeeksUpcomingInspectionList();
}
